@@ -291,15 +291,15 @@ class Config(object):
         with open(output, 'w') as f:
             if comments:
                 f.write("#####################################\n")
-                f.write("Description :\n")
-                f.write("-------------\n")
+                f.write("# Description :\n")
+                f.write("# -------------\n# ")
                 f.write(self._desc)
                 f.write("\n\n")
 
             for s in self.sections.values():
                 log.debug("loading section : " + s.get_section_name())
                 s.write_config_file(f, comments)
-        log.debug("config file generation complete : " + str(output))
+        log.debug("config file generation completed : " + str(output))
 
 
 # -----------------------------------------------------------------------------
@@ -357,7 +357,7 @@ class _AbstractSection(object):
         """
         if comments:
             f.write("#####################################\n")
-            f.write("# Section : " + "".join(self.get_representation()) + "\n")
+            f.write("# Section : " + "#".join(self.get_representation()) + "\n")
             f.write("#####################################\n")
         f.write("[" + self._name + "]\n")
         if self._desc and comments:
